// Build don't link:
// crash test -

// by Paul Burchard <burchard@pobox.com>, Level Set Systems, Inc.
// Copyright (C) 1999 Free Software Foundation

typedef std::vector<int>::iterator iter; // ERROR - syntax error before `::'

